@@ -1,9 +1,9 @@
 package Sah::Schema::rinci::function_meta;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-27'; # DATE
+our $DATE = '2020-09-23'; # DATE
 our $DIST = 'Sah-Schemas-Rinci'; # DIST
-our $VERSION = '1.1.90.1'; # VERSION
+our $VERSION = '1.1.94.0'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,6 +103,8 @@ our $schema = [hash => {
                 src_plang => {},
                 status => {},
                 result => {},
+                naked_result => {},
+                env_result => {},
                 test => {},
             },
         },
@@ -167,7 +169,7 @@ Sah::Schema::rinci::function_meta - Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 1.1.90.1 of Sah::Schema::rinci::function_meta (from Perl distribution Sah-Schemas-Rinci), released on 2020-05-27.
+This document describes version 1.1.94.0 of Sah::Schema::rinci::function_meta (from Perl distribution Sah-Schemas-Rinci), released on 2020-09-23.
 
 =head1 SYNOPSIS
 
